@@ -19,40 +19,67 @@ except NameError:
 
 log = logging.getLogger(__name__)
 
+
 def jsonprint(value):
     return json.dumps(value, indent=2, separators=(',', ': '))
 
+
+def get_db_version(puppetdb):
+    '''
+    Get the version of puppetdb.  Version form 3.2 query
+    interface is slightly different on mbeans
+    '''
+    ver = ()
+    try:
+        version = puppetdb.current_version()
+        (major, minor, build) = [int(x) for x in version.split('.')]
+        ver = (major, minor, build)
+        log.info("PuppetDB Version %d.%d.%d" % (major, minor, build))
+    except ValueError as e:
+        log.error("Unable to determine version from string: '%s'" % version)
+        ver = (4, 2, 0)
+    except HTTPError as e:
+        log.error(str(e))
+    except ConnectionError as e:
+        log.error(str(e))
+    except EmptyResponseError as e:
+        log.error(str(e))
+    return ver
+
+
 def formatvalue(value):
     if isinstance(value, str):
-      return value
+        return value
     elif isinstance(value, list):
-      return ", ".join(value)
+        return ", ".join(value)
     elif isinstance(value, dict):
-      ret = ""
-      for k in value:
-        ret += k+" => "+formatvalue(value[k])+",<br/>"
-      return ret
+        ret = ""
+        for k in value:
+            ret += k + " => " + formatvalue(value[k]) + ",<br/>"
+        return ret
     else:
-      return str(value)
+        return str(value)
+
 
 def prettyprint(value):
     html = '<table class="ui basic fixed sortable table"><thead><tr>'
 
     # Get keys
     for k in value[0]:
-      html += "<th>"+k+"</th>"
+        html += "<th>" + k + "</th>"
 
     html += "</tr></thead><tbody>"
 
     for e in value:
         html += "<tr>"
         for k in e:
-          html += "<td>"+formatvalue(e[k])+"</td>"
+            html += "<td>" + formatvalue(e[k]) + "</td>"
         html += "</tr>"
 
     html += "</tbody></table>"
     return(html)
 
+
 def get_or_abort(func, *args, **kwargs):
     """Execute the function with its arguments and handle the possible
     errors that might occur.
@@ -86,35 +113,3 @@ def yield_or_stop(generator):
             raise
         except (EmptyResponseError, ConnectionError, HTTPError):
             raise StopIteration
-
-class Pagination(object):
-
-    def __init__(self, page, per_page, total_count):
-        self.page = page
-        self.per_page = per_page
-        self.total_count = total_count
-
-    @property
-    def pages(self):
-        return int(ceil(self.total_count / float(self.per_page)))
-
-    @property
-    def has_prev(self):
-        return self.page > 1
-
-    @property
-    def has_next(self):
-        return self.page < self.pages
-
-    def iter_pages(self, left_edge=2, left_current=2,
-                   right_current=5, right_edge=2):
-        last = 0
-        for num in xrange(1, self.pages + 1):
-            if num <= left_edge or \
-               (num > self.page - left_current - 1 and \
-                num < self.page + right_current) or \
-                num > self.pages - right_edge:
-                if last + 1 != num:
-                    yield None
-                yield num
-                last = num
